# CREDITS: this example is adapted from the pygame website
#          https://www.pygame.org/docs/tut/PygameIntro.html

import pygame


WIDTH = 640
HEIGHT = 480

FPS = 60

pygame.init()

BLACK = (0, 0, 0)


class Ball:
    """
    A class used to represent a beachball in pygame

    Attributes
    ----------
    speed_x (int): the speed in the x direction
    speed_y (int): the speed in the y direction
    image (pygame.surface.Surface): a pygame representation of the beachball image
    ball_rect (pygame.rect.Rect): a pygame rect object representing the position of the ball

    Methods
    -------
    update()
        updates the speed of the ball given the current position.

    render(screen)
        Renders the ball image on the screen
    """
    def __init__(self):
        """
        Initializes a Ball object, loads the image

        Args: N/A
        """
        self.speed_x = 2
        self.speed_y = 2
        self.image = pygame.image.load("intro_ball.gif")
        self.ball_rect = self.image.get_rect()
        
    def update(self):
        """
        Updates the speed of the ball given the current position.

        Args: N/A

        Returns: None
        """
        self.ball_rect = self.ball_rect.move((self.speed_x, self.speed_y))
        if self.ball_rect.left < 0 or self.ball_rect.right > WIDTH:
            self.speed_x *= -1
        if self.ball_rect.top < 0 or self.ball_rect.bottom > HEIGHT:
            self.speed_y *= -1
            
    def render(self, screen):
        """
        Renders the beachball on it's current position on the screen

        Args:
            screen (pygame.surface.Surface): the screen object

        Returns: None
        """
        screen.blit(self.image, self.ball_rect.topleft)


def play_game():
    """
    Plays the "game", really just a beachball moving around

    Arguments: N/A
    
    Returns: None
    """
    screen = pygame.display.set_mode((WIDTH, HEIGHT))
    clock = pygame.time.Clock()

    ball = Ball()
        
    # Main game loop
    while True:

        # make the background black again
        screen.fill(BLACK)

        # Obtain any user inputs
        event = pygame.event.poll()
        if event.type == pygame.QUIT:
          break

        ball.update()
        
        # render the paddle and the ball
        ball.render(screen)
        
        # Render next frame
        pygame.display.update()
        clock.tick(FPS)

        
if __name__ == "__main__":
    play_game()
